@@ -37,6 +37,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</small>
 #include <WinSock2.h>
 #include <ws2tcpip.h>
 
+#if defined (iPlatformWindows)
+typedef int iSockResult;
+#else
+typedef ssize_t iSockResult;
+#endif
+
 static const int connectionTimeoutSeconds_Socket_ = 6;
 
 /* address.c */
@@ -127,7 +133,7 @@ static iThreadResult run_SocketThread_(iThread *thread) {
         WSANETWORKEVENTS netEvents;
         WSAEnumNetworkEvents(d->socket->fd, d->socket->fdEvent, &netEvents);
         if (netEvents.lNetworkEvents & FD_READ) {
-            ssize_t readSize = recv(d->socket->fd, data_Block(inbuf), size_Block(inbuf), 0);
+            iSockResult readSize = recv(d->socket->fd, data_Block(inbuf), size_Block(inbuf), 0);
             if (readSize == 0) {
                 iWarning("[Socket] peer closed the connection while we were receiving\n");
                 shutdown_Socket_(d->socket);
@@ -171,9 +177,9 @@ static iThreadResult run_SocketThread_(iThread *thread) {
                 const char * ptr         = constData_Block(data);
                 const size_t totalToSend = remaining = size_Block(data);
                 while (remaining > 0) {
-                    ssize_t sent = send(d->socket->fd, ptr, remaining, 0);
+                    iSockResult sent = send(d->socket->fd, ptr, remaining, 0);
                     if (sent == -1) {
-                        /* Error! */                        
+                        /* Error! */
 #if defined (iHaveDebugOutput)
                         const DWORD err = WSAGetLastError();
                         iWarning("[Socket] peer closed the connection while we were sending "
@@ -489,7 +495,7 @@ iSocket *newAddress_Socket(const iAddress *address) {
     return d;
 }
 
-iSocket *newExisting_Socket(int fd, const void *sockAddr, size_t sockAddrSize) {
+iSocket *newExisting_Socket(iNativeSocket fd, const void *sockAddr, size_t sockAddrSize) {
     iSocket *d = iNew(Socket);
     init_Socket_(d);
     d->fd = fd;
