@@ -35,7 +35,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</small>
 #include <the_Foundation/hash.h>
 #include <the_Foundation/map.h>
 #include <the_Foundation/math.h>
-#include <the_Foundation/hash.h>
 #include <the_Foundation/object.h>
 #include <the_Foundation/objectlist.h>
 #include <the_Foundation/path.h>
@@ -45,15 +44,15 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.</small>
 #include <the_Foundation/sortedarray.h>
 #include <the_Foundation/string.h>
 #include <the_Foundation/stringarray.h>
-#include <the_Foundation/stringlist.h>
 #include <the_Foundation/stringhash.h>
-#include <the_Foundation/time.h>
+#include <the_Foundation/stringlist.h>
 #include <the_Foundation/thread.h>
+#include <the_Foundation/time.h>
 #include <the_Foundation/xml.h>
 
+#include <locale.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <locale.h>
 #include <time.h>
 
 /*-------------------------------------------------------------------------------------*/
@@ -63,7 +62,7 @@ iDeclareType(TestObject)
 
 struct Impl_TestObject {
     iObject object;
-    int value;
+    int     value;
 };
 
 static void deinit_TestObject(iAnyObject *any) {
@@ -82,9 +81,10 @@ iTestObject *new_TestObject(int value) {
 /*-------------------------------------------------------------------------------------*/
 
 void printArray(const iArray *d) {
-    printf("%4lu %4lu -> %-4lu : %4lu [", size_Array(d), d->range.start, d->range.end, d->allocSize);
+    printf(
+        "%4zu %4zu -> %-4zu : %4zu [", size_Array(d), d->range.start, d->range.end, d->allocSize);
     for (size_t i = 0; i < d->allocSize * d->elementSize; ++i) {
-        if (i/d->elementSize < d->range.start || i/d->elementSize >= d->range.end)
+        if (i / d->elementSize < d->range.start || i / d->elementSize >= d->range.end)
             printf(" _");
         else
             printf(" %c", d->data[i]);
@@ -101,7 +101,7 @@ static void printBytes(const uint8_t *data, size_t size) {
 }
 
 static void printIntArray(const iArray *d) {
-    printf("%4lu :", size_Array(d));
+    printf("%4zu :", size_Array(d));
     iConstForEach(Array, i, d) {
         printf(" %2i", *(const int *) i.value);
     }
@@ -109,7 +109,7 @@ static void printIntArray(const iArray *d) {
 }
 
 static void printIntPairArray(const iArray *d) {
-    printf("%4lu :", size_Array(d));
+    printf("%4zu :", size_Array(d));
     iConstForEach(Array, i, d) {
         const int *pair = (const int *) i.value;
         printf(" (%2i, %2i)", pair[0], pair[1]);
@@ -140,7 +140,7 @@ static int compareTestObjects(const void *a, const void *b) {
     const iTestObject *x = object_ObjectListNode(a);
     const iTestObject *y = object_ObjectListNode(b);
     iAssert(a != b);
-    //iDebug("comparing: (%p) %i and (%p) %i\n", x, x->value, y, y->value);
+    // iDebug("comparing: (%p) %i and (%p) %i\n", x, x->value, y, y->value);
     return iCmp(x->value, y->value);
 }
 
@@ -158,26 +158,28 @@ int main(int argc, char *argv[]) {
         iCommandLine *cmdline = iClob(new_CommandLine(argc, argv));
         defineValues_CommandLine(cmdline, "file;f", unlimitedValues_CommandLine);
         defineValues_CommandLine(cmdline, "value;V", 1);
-        printf("Executable: \"%s\"\n", cstr_String(executablePath_CommandLine(cmdline)));
-        printf("Working directory: \"%s\"\n", cstr_String(collect_String(cwd_Path())));
+        printf("Executable: \"%s\"\n", cstrConsole_String(executablePath_CommandLine(cmdline)));
+        printf("Working directory: \"%s\"\n", cstrConsole_String(collect_String(cwd_Path())));
+        printf("Home directory: \"%s\"\n", cstrConsole_String(collect_String(home_Path())));
         puts("Options from command line:");
         iConstForEach(StringList, i, args_CommandLine(cmdline)) {
-            printf("%2zu: \"%s\"\n", i.pos, cstrLocal_String(i.value));
+            printf("%2zu: \"%s\"\n", i.pos, cstrConsole_String(i.value));
         }
         puts("Iterated:");
         iConstForEach(CommandLine, j, cmdline) {
             iString *e = newRange_String(j.entry);
             printf("[%2zu] %5s vc:%zu \"%s\"\n",
                    j.value,
-                   ( j.argType == value_CommandLineArgType? "value"
-                   : j.argType == shortArgument_CommandLineArgType? "short" : "long" ),
+                   (j.argType == value_CommandLineArgType           ? "value"
+                    : j.argType == shortArgument_CommandLineArgType ? "short"
+                                                                    : "long"),
                    j.valueCount,
-                   cstrLocal_String(e));
+                   cstrConsole_String(e));
             const iCommandLineArg *arg = argument_CommandLineConstIterator(&j);
             if (arg && !isEmpty_StringList(values_CommandLineArg(arg))) {
-                printf("  arguments for \"%s\":\n", cstrLocal_String(&arg->arg));
+                printf("  arguments for \"%s\":\n", cstrConsole_String(&arg->arg));
                 iConstForEach(StringList, i, values_CommandLineArg(arg)) {
-                    printf("    %2zu: \"%s\"\n", i.pos, cstrLocal_String(i.value));
+                    printf("    %2zu: \"%s\"\n", i.pos, cstrConsole_String(i.value));
                 }
                 iRelease(arg);
             }
@@ -190,10 +192,10 @@ int main(int argc, char *argv[]) {
             iConstForEach(StringList, k, values_CommandLineArg(arg)) {
                 iString *clean = copy_String(k.value);
                 clean_Path(clean);
-                printf(" %s", cstrLocal_String(clean));
+                printf(" %s", cstrConsole_String(clean));
                 delete_String(clean);
                 iString *abso = makeAbsolute_Path(k.value);
-                printf("\n  absolute: %s", cstrLocal_String(abso));
+                printf("\n  absolute: %s", cstrConsole_String(abso));
                 printf("\n  file exists: %s\n", fileExists_FileInfo(abso) ? "yes" : "no");
                 delete_String(abso);
             }
@@ -201,7 +203,7 @@ int main(int argc, char *argv[]) {
         }
         arg = iClob(checkArgumentValues_CommandLine(cmdline, "V;value", 1));
         if (arg) {
-            printf("value option: %s\n", cstrLocal_String(value_CommandLineArg(arg, 0)));
+            printf("value option: %s\n", cstrConsole_String(value_CommandLineArg(arg, 0)));
         }
         if (contains_CommandLine(cmdline, "x")) {
             puts("x option");
@@ -223,6 +225,16 @@ int main(int argc, char *argv[]) {
             printf("parsing %s\n", ok ? "succeeded" : "failed!");
             delete_XmlDocument(doc);
             iRelease(f);
+            deinit_Foundation();
+            return 0;
+        }
+        arg = iClob(checkArgumentValues_CommandLine(cmdline, "m", 1));
+        if (arg) {
+            const iString *dir = value_CommandLineArg(arg, 0);
+            printf("mkdir: %s (%s)\n", cstrConsole_String(dir), mkdir_Path(dir) ? "ok" : "fail");
+            printf("chdir: %s\n", setCwd_Path(dir) ? "ok" : "fail");
+            printf("cwd: %s\n", cstrConsole_String(collect_String(cwd_Path())));
+            deinit_Foundation();
             return 0;
         }
     }
@@ -232,28 +244,35 @@ int main(int argc, char *argv[]) {
         init_Date(&date, &now);
         printf("sizeof(iTime) == %zu bytes\n", sizeof(iTime));
         printf("sizeof(iDate) == %zu bytes\n", sizeof(iDate));
-        printf("Today is %i-%02i-%02i (week day %i) and the time is %02i:%02i:%02i.%li (GMT offset: %li mins)\n",
-               date.year, date.month, date.day, date.dayOfWeek,
-               date.hour, date.minute, date.second, date.nsecs,
-               date.gmtOffsetSeconds/60);
+        printf("Today is %i-%02i-%02i (week day %i) and the time is %02i:%02i:%02i.%li (GMT "
+               "offset: %li mins)\n",
+               date.year,
+               date.month,
+               date.day,
+               date.dayOfWeek,
+               date.hour,
+               date.minute,
+               date.second,
+               date.nsecs,
+               date.gmtOffsetSeconds / 60);
     }
     /* File information. */ {
         iBeginCollect();
         iForEach(DirFileInfo, i, iClob(newCStr_DirFileInfo("."))) {
-            printf("%10li %s %12li %s\n",
+            printf("%10zu %s %s %12lli %s\n",
                    size_FileInfo(i.value),
-                   isDirectory_FileInfo(i.value)? "(dir)" : "     ",
-                   lastModified_FileInfo(i.value).ts.tv_sec,
-                   cstrLocalPath_FileInfo(i.value));
+                   isDirectory_FileInfo(i.value) ? "(dir)" : "     ",
+                   isWritable_FileInfo(i.value) ? "    " : "(ro)",
+                   (long long int) lastModified_FileInfo(i.value).ts.tv_sec,
+                   cstrConsole_String(path_FileInfo(i.value)));
         }
         iEndCollect();
     }
     /* Test array insertion and removal. */ {
         puts("Array insertions/removals:");
         iArray *list = new_Array(2);
-        printArray(list);
-        {
-            puts("Iterating the empty array:");
+        printArray(list); {
+            puts("  Iterating the empty array.");
             iForEach(Array, i, list) {
                 printf("- %p\n", i.value);
             }
@@ -315,7 +334,7 @@ int main(int argc, char *argv[]) {
         iPtrArray *par = newPointers_PtrArray("Entry One", "Entry Two", NULL);
         puts("Iterating the pointer array:");
         iConstForEach(PtrArray, i, par) {
-            printf("- %s\n", i.ptr);
+            printf("- %s\n", (const char *) i.ptr);
         }
         delete_PtrArray(par);
     }
@@ -362,7 +381,7 @@ int main(int argc, char *argv[]) {
     }
     /* Test a hash. */ {
         iHash *h = new_Hash();
-        for (int i = 0; i < 8/*192*/; ++i) {
+        for (int i = 0; i < 8 /*192*/; ++i) {
             iHashNode *node = iCollectMem(iMalloc(HashNode));
             for (;;) {
                 node->key = iRandomu(0, RAND_MAX);
@@ -372,7 +391,7 @@ int main(int argc, char *argv[]) {
                 }
             }
         }
-        printf("Hash iteration (size %zu):", size_Hash(h));
+        printf("Hash iteration (size %zu):\n", size_Hash(h));
         int counter = 0;
         iForEach(Hash, i, h) {
             printf("%4i: %i\n", counter++, i.value->key);
@@ -402,11 +421,11 @@ int main(int argc, char *argv[]) {
             }
         }
         puts(" ]");
-        const int fullSize = size_Map(map);
+        const size_t fullSize = size_Map(map);
         iDebugOnly(fullSize);
         int remCount = 0;
         for (int i = 0; i < 300; ++i) {
-            iMapKey key = iRandom(0, 100);
+            iMapKey   key = iRandom(0, 100);
             iMapNode *rem = remove_Map(map, key);
             if (rem) {
                 remCount++;
@@ -414,6 +433,7 @@ int main(int argc, char *argv[]) {
             }
         }
         iAssert((size_t) (fullSize - remCount) == size_Map(map));
+        iUnused(remCount);
         printf("Size after removals: %zu\n", size_Map(map));
         delete_Map(map);
         iEndCollect();
@@ -445,12 +465,12 @@ int main(int argc, char *argv[]) {
     /* Test a thread. */ {
         iThread *worker = new_Thread(run_WorkerThread);
         start_Thread(worker);
-        printf("Result from worker: %li\n", result_Thread(worker));
+        printf("Result from worker: %i\n", (int) result_Thread(worker));
         iAssert(result_Thread(worker) == 12345);
         iRelease(worker);
     }
     /* Test a file. */ {
-        remove("test.txt");
+        removePath_CStr("test.txt");
         iFile *f = newCStr_File("test.txt");
         if (open_File(f, writeOnly_FileMode | text_FileMode)) {
             const char *ln = "line 1\nline 2\n";
@@ -462,7 +482,7 @@ int main(int argc, char *argv[]) {
             size_t n = 30;
             while (!atEnd_File(f)) {
                 size_t fpos = pos_File(f);
-                int ch = read8_File(f);
+                int    ch   = read8_File(f);
                 printf("%4zu: %02X", fpos, ch);
                 if (ch > ' ' && ch < 128) printf(" [%c]", ch);
                 printf("\n");
@@ -506,7 +526,10 @@ int main(int argc, char *argv[]) {
         init_RegExpMatch(&match);
         while (matchString_RegExp(rx, s, &match)) {
             iString *cap = captured_RegExpMatch(&match, 1);
-            printf("match: %i -> %i [%s]\n", match.range.start, match.range.end, cstrLocal_String(cap));
+            printf("match: %i -> %i [%s]\n",
+                   match.range.start,
+                   match.range.end,
+                   cstrConsole_String(cap));
             delete_String(cap);
         }
         iRelease(rx);
@@ -536,7 +559,8 @@ int main(int argc, char *argv[]) {
         const iString domain = iStringLiteral("räksmörgås");
         iString *puny = collect_String(punyEncode_Rangecc(range_String(&domain)));
         iString *dec = collect_String(punyDecode_Rangecc(range_String(puny)));
-        printf("%s => %s => %s\n", cstrLocal_String(&domain), cstr_String(puny), cstrLocal_String(dec));
+        printf("%s => %s => %s\n", cstrConsole_String(&domain), cstr_String(puny), cstrConsole_String(dec));
     }
+    deinit_Foundation();
     return 0;
 }
